'use strict';

const module$1 = require('module');
const path = require('path');
const process = require('process');
const constant = require('@babel/plugin-transform-react-constant-elements');
const env = require('@babel/preset-env');
const react = require('@babel/preset-react');
const typescript = require('@babel/preset-typescript');
const commonjs = require('@mo36924/babel-plugin-commonjs');
const deadCodeElimination = require('@mo36924/babel-plugin-dead-code-elimination');
const iifeUnwrap = require('@mo36924/babel-plugin-iife-unwrap');
const inject = require('@mo36924/babel-plugin-inject');
const jsxDev = require('@mo36924/babel-plugin-jsx-development');
const replace = require('@mo36924/babel-plugin-replace');
const _resolve = require('@mo36924/babel-plugin-resolve');
const subpath = require('@mo36924/babel-plugin-resolve-subpath');
const reactRefresh = require('react-refresh/babel');

const _interopDefault = e => e && e.__esModule ? e : { default: e };

const process__default = /*#__PURE__*/_interopDefault(process);
const constant__default = /*#__PURE__*/_interopDefault(constant);
const env__default = /*#__PURE__*/_interopDefault(env);
const react__default = /*#__PURE__*/_interopDefault(react);
const typescript__default = /*#__PURE__*/_interopDefault(typescript);
const commonjs__default = /*#__PURE__*/_interopDefault(commonjs);
const deadCodeElimination__default = /*#__PURE__*/_interopDefault(deadCodeElimination);
const iifeUnwrap__default = /*#__PURE__*/_interopDefault(iifeUnwrap);
const inject__default = /*#__PURE__*/_interopDefault(inject);
const jsxDev__default = /*#__PURE__*/_interopDefault(jsxDev);
const replace__default = /*#__PURE__*/_interopDefault(replace);
const _resolve__default = /*#__PURE__*/_interopDefault(_resolve);
const subpath__default = /*#__PURE__*/_interopDefault(subpath);
const reactRefresh__default = /*#__PURE__*/_interopDefault(reactRefresh);

const _require = module$1.createRequire(path.resolve("index.js"));
const { NODE_ENV, NODE_TARGET, NODE_NOMODULE } = process__default.default.env;
const index = (_api, options) => {
    const { env: __ENV__ = NODE_ENV ?? "production", target: __TARGET__ = NODE_TARGET ?? "server", nomodule = NODE_NOMODULE !== "false" && !!NODE_NOMODULE, jsx = "react", inject: _inject = {}, replace: _replace = {}, exports = {}, } = options;
    if (jsx === "react") {
        for (const mod of [
            "react",
            "react-dom",
            "react-dom/server",
            "react-dom/server.browser",
            "react/jsx-runtime",
            "react/jsx-dev-runtime",
        ]) {
            try {
                exports[mod] = Object.keys(_require(mod));
            }
            catch { }
        }
    }
    const __PROD__ = __ENV__ === "production" || undefined;
    const __DEV__ = __ENV__ === "development" || undefined;
    const __TEST__ = __ENV__ === "test" || undefined;
    const __SERVER__ = __TARGET__ === "server" || undefined;
    const __CLIENT__ = !__SERVER__ || undefined;
    const __NOMODULE__ = (__CLIENT__ && nomodule) || undefined;
    return {
        presets: [
            [
                env__default.default,
                {
                    bugfixes: true,
                    modules: false,
                    loose: false,
                    ignoreBrowserslistConfig: true,
                    targets: !__PROD__
                        ? {
                            node: "14",
                            chrome: "83",
                        }
                        : __SERVER__
                            ? {
                                node: "14",
                            }
                            : __NOMODULE__
                                ? {
                                    android: "4.4",
                                    chrome: "41",
                                    edge: "16",
                                    firefox: "60",
                                    ie: "11",
                                    ios: "10.3",
                                    opera: "48",
                                    safari: "10.1",
                                    samsung: "8.2",
                                }
                                : {
                                    esmodules: true,
                                },
                    useBuiltIns: __PROD__ ? "usage" : false,
                    corejs: __PROD__ ? "3.10" : undefined,
                },
            ],
            [typescript__default.default],
            [
                react__default.default,
                {
                    runtime: "automatic",
                    development: __DEV__,
                    importSource: jsx,
                },
            ],
        ],
        plugins: [
            [
                replace__default.default,
                {
                    ..._replace,
                    "typeof self": __SERVER__ ? '"undefined"' : '"object"',
                    "typeof global": __SERVER__ ? '"object"' : '"undefined"',
                    "typeof process": '"object"',
                    "process.env.NODE_ENV": `"${__ENV__}"`,
                    __ENV__: `"${__ENV__}"`,
                    __TARGET__: `"${__TARGET__}"`,
                    __PROD__,
                    __DEV__,
                    __TEST__,
                    __SERVER__,
                    __CLIENT__,
                    __NOMODULE__,
                    ...(__NOMODULE__ ? {} : { "typeof Event": __SERVER__ ? '"undefined"' : '"function"' }),
                    ...(__SERVER__ && { "typeof window": '"undefined"' }),
                },
            ],
            [deadCodeElimination__default.default],
            [iifeUnwrap__default.default],
            [
                _resolve__default.default,
                __PROD__
                    ? false
                    : {
                        ignoreBuiltins: __SERVER__,
                        ignoreBareImport: __SERVER__ && !__PROD__,
                        aliasFields: __SERVER__ ? [] : ["browser"],
                        mainFields: __SERVER__ ? ["module", "main"] : ["browser", "module", "main"],
                        conditionNames: __SERVER__ ? ["import"] : ["browser", "import"],
                        baseUrl: ".",
                        paths: { "~/": "./" },
                        alias: jsx === "preact"
                            ? {
                                react: "preact/compat",
                                "react-dom": "preact/compat",
                            }
                            : {},
                        extensions: __SERVER__
                            ? [
                                ".server.tsx",
                                ".server.ts",
                                ".server.jsx",
                                ".server.mjs",
                                ".server.js",
                                ".server.cjs",
                                ".server.json",
                                ".tsx",
                                ".ts",
                                ".jsx",
                                ".mjs",
                                ".js",
                                ".cjs",
                                ".json",
                                ".node",
                            ]
                            : [
                                ".client.tsx",
                                ".client.ts",
                                ".client.jsx",
                                ".client.mjs",
                                ".client.js",
                                ".client.cjs",
                                ".client.json",
                                ".tsx",
                                ".ts",
                                ".jsx",
                                ".mjs",
                                ".js",
                                ".cjs",
                                ".json",
                                ".node",
                            ],
                    },
            ],
            [subpath__default.default, __SERVER__ ? {} : false],
            [commonjs__default.default, __SERVER__ ? false : exports],
            [
                inject__default.default,
                {
                    declarations: {
                        ..._inject,
                    },
                },
            ],
            [reactRefresh__default.default, false],
            [jsxDev__default.default, __PROD__ ? false : {}],
            [constant__default.default, __PROD__ ? {} : false],
        ],
        overrides: [
            {
                test: /\.(j|t)sx$/,
                plugins: [[reactRefresh__default.default, __DEV__ ? {} : false]],
            },
        ],
    };
};

module.exports = index;
//# sourceMappingURL=index.cjs.map
